@@ -18,7 +18,7 @@ use Template::Provider;
 use IPC::Open2;
 use base qw/App::TemplateCMD::Command/;
 
-our $VERSION     = version->new('0.6.0');
+our $VERSION     = version->new('0.6.1');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -36,8 +36,6 @@ sub process {
     my $out = '';
     $cmd->{template}->process( $template, $args, \$out );
     warn  $cmd->{template}->error . "\n" if $cmd->{template}->error && $cmd->{template}->error !~ /^file error - .*: not a file$/;
-    $Data::Dumper::Indent = 1;
-    print Dumper $cmd->{template};
 
     if (!$out) {
         my @files = uniq sort map {$_->{file}} $cmd->list_templates();
@@ -124,7 +122,7 @@ App::TemplateCMD::Command::Print - Prints a parsed template out to screen or fil
 
 =head1 VERSION
 
-This documentation refers to App::TemplateCMD::Command::Print version 0.6.0.
+This documentation refers to App::TemplateCMD::Command::Print version 0.6.1.
 
 =head1 SYNOPSIS
 
